@@ -1,3 +1,11 @@
+from pkg_resources import get_distribution
+
+try:
+    __version__ = get_distribution('circlator').version
+except:
+    __version__ = 'local'
+
+
 __all__ = [
     'assemble',
     'assembly',
@@ -12,6 +20,7 @@ __all__ = [
     'minimus2',
     'program',
     'tasks',
+    'versions',
 ]
 
 from circlator import *
